from pageo.base_page import BasePage
from pageo.locators import IdLocator
from pageo.locators import ClassNameLocator
from pageo.locators import CSSLocator
from pageo.locators import NameLocator
from pageo.locators import LinkTextLocator
from pageo.locators import PartialLinkTextLocator
from pageo.locators import XPATHLocator
from pageo.locators import TagNameLocator
