from pageo.locators.id_locator import IdLocator
from pageo.locators.class_name_locator import ClassNameLocator
from pageo.locators.css_locator import CSSLocator
from pageo.locators.name_locator import NameLocator
from pageo.locators.link_text_locator import LinkTextLocator
from pageo.locators.partial_link_text_locator import PartialLinkTextLocator
from pageo.locators.xpath_locator import XPATHLocator
from pageo.locators.tag_name_locator import TagNameLocator
